Far
=========

[![PyPI Version](https://img.shields.io/pypi/v/far.svg)](https://pypi.python.org/pypi/far) [![PyPI Downloads](https://img.shields.io/pypi/dm/far.svg)](https://pypi.python.org/pypi/far) [![PyPI License](https://img.shields.io/pypi/l/far.svg)](https://pypi.python.org/pypi/far) [![GitHub tag](https://img.shields.io/github/tag/shubhamchaudhary/far.svg)](https://github.com/shubhamchaudhary/far/releases) [![GitHub release](https://img.shields.io/github/release/shubhamchaudhary/far.svg)](https://github.com/shubhamchaudhary/far/releases/latest)

[![Build Status Travis-CI](https://travis-ci.org/shubhamchaudhary/far.svg)](https://travis-ci.org/shubhamchaudhary/far) [![Coverage Status](https://coveralls.io/repos/shubhamchaudhary/far/badge.svg?branch=master)](https://coveralls.io/r/shubhamchaudhary/far?branch=master) [![Build Status Snap-CI](https://snap-ci.com/shubhamchaudhary/far/branch/master/build_image)](https://snap-ci.com/shubhamchaudhary/far/branch/master) [![Requirements Status](https://requires.io/github/shubhamchaudhary/far/requirements.svg?branch=master)](https://requires.io/github/shubhamchaudhary/far/requirements/?branch=master)

[![GitHub issues](https://img.shields.io/github/issues/shubhamchaudhary/far.svg?style=plastic)](https://github.com/shubhamchaudhary/far/issues) [![Stories in Ready](https://badge.waffle.io/shubhamchaudhary/far.png?label=ready&title=Ready)](https://waffle.io/shubhamchaudhary/far)


```
find . -type f -not -path '*/\.git*' -exec sed -i 's/foo/bar/g' {} + 
```

Why is doing a find and replace with pattern so messy?  

Let's _find_ a solution for this problem.  

#### Installation
Far will be available from PyPi

```
# pip install far
```


#### Contributors
Checkout CONTRIBUTION.md file
